@@ -12,11 +12,13 @@ from fast_tracker.client import TraceSegmentReportService
 from fast_tracker.report.report_struct import ReportStruct
 from fast_tracker.utils import functions
 
+DEFAULT_UDP_IP = "127.0.0.1"
+DEFAULT_UDP_PORT = 5140
 
 class UdpTraceSegmentReportService(TraceSegmentReportService):
     def __init__(self):
-        self.udp_ip = ""
-        self.udp_port = 80
+        self.udp_ip = DEFAULT_UDP_IP
+        self.udp_port = DEFAULT_UDP_PORT
         if config.collector_address:
             self._init_ip_and_port(config.collector_address)
         self.buffer_size = config.buffer_size
@@ -46,7 +48,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             self.udp_port = int(self.udp_port)
         elif len(connections) == 3:
             self.udp_ip = connections[1].strip("//")
-            self.udp_port = int(connections[2]) if len(connections) > 2 else 80
+            self.udp_port = int(connections[2]) if len(connections) > 2 else DEFAULT_UDP_PORT
         else:
             functions.log("socket_path参数不合法")
             return False
@@ -69,8 +71,12 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
                     functions.log("udp socket object get data", level=4)
                     res = udp_sock.sendto(data, (self.udp_ip, self.udp_port))
                     # res = udp_sock.sendto(data, ("fluent-bit", 5140))
-                    functions.log("udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
+                    functions.log("sended udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
                     functions.log("sended message: %r, result is: %r", data, res)
+                # segment上报完清除用户自定义字段值，避免污染之后的上报
+                config.custom_env_code = ""
+                config.custom_tenant_code = ""
+                config.custom_user_code = ""
         except BaseException as e:
             functions.log("udp report error: %r", e)
 
